<!-- Thank you for your contribution! The following items must be addressed before the code can be merged. Please don't hesitate to ask for help if you're unsure of how to accomplish any of the items. Feel free to remove checklist items that are not relevant to your change. -->

- [ ] Closes #xxxx
- [ ] I am familiar with the
      [contributing guidelines](https://github.com/Saransh-cpp/riemapp/blob/main/CONTRIBUTING.md)
- [ ] Tests added
- [ ] New code is fully documented. Includes compliant docstrings, examples, and
      comments where necessary.
- [ ] Pull request is nearly complete and ready for detailed review.

<!-- Brief description of the problem and proposed solution: -->
